==> nextcloud-app-tasks-0.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/es_CO.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Can edit" : "Puede editar",
    "Edit" : "Editar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vacíar la papelera",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repetir",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/es_CO.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Can edit" : "Puede editar",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Edit" : "Editar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Empty trash bin" : "Vacíar la papelera",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Cancel" : "Cancelar",
    "Email" : "Correo electrónico",
    "Go back" : "Regresar",
    "Close" : "Cerrar",
    "Select tags to filter by" : "Selecciona las etiquetas del filtro",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Tags" : "Etiquetas",
    "Manually" : "Manualmente",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Delete task" : "Eliminar tarea",
    "Task is completed" : "La tarea ha sido completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
